yakumo.nova.v2.floating_ip_bulk

Package yakumo :: Package nova :: Package v2 :: Module floating_ip_bulk |
[hide private]
[frames] | no frames]

# Module floating_ip_bulk

source code

Resource class and its manager for floating IP bulks in Compute API v2

Classes | [hide private]
| Resource Resource class for floating IP bulks in Compute API v2
| Manager Manager class for floating IP bulks in Compute API v2

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``ip``'``,` `'``address``'``,` <yakumo.mapper.NoopClas`...``
| __package__ = ``'``yakumo.nova.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('ip', 'address', mapper.Noop), ('ip_range', 'ip_range', mapper.Noop)
      , ('server', 'instance_uuid', mapper.Resource('nova.server')), ('inter
      face', 'interface', mapper.Noop), ('project', 'project_id', mapper.Res
      ource('project')),]